function [Ceqdef,Jacdef] = DefSep_Comb(nvar,into,colind,scl,def)

% This function defines the definition values in the reaction
% section of the simple ammonia loop. It can be modified to define the
% flowsheet differently. The definitions in this file are given by:
%
%   Cold inlet HEx6	Q, p, T, and xi
%
% It is used for the combined flowsheet.
% Written by Julian Straus, Trondheim 09.12.2018
%
% The input of this function is given by
%       nvar:   Total number of variables.
%
%       into:   Input values to the unit operation defined in the
%               flowsheet.
%
%       colind: Indexes of the columns i the Jacobian.
%
% The main output is defined as
%       Ceqdef: Cells containing the equality constraints of the
%               definitions.
%
%       Jacdef: Cells containing the rows of the Jacobian defined by the
%               definitions.
%
% The necessary structures and cells are defined as
%       scl:    Scaling factors of the system defined in cells representing
%               the unit operations defined in par.ReactSec.
%
%       def:    Defined stream values, e.g pressure and composition for all
%               inlets and the pressure of the outlets or the flow of the
%               inlets.

% Predefinition of the returning cells.
Jacdef = cell(def.sizeMat);
Ceqdef = Jacdef;
                                  
%% Definitions in Heat Exchanger 6

k = 1;
% Calculation of the equality constraints for the definition of heat exchanger 1
Ceqdef{k+1} = (into{k}(17:24).*scl{k}.Var(17:24)'-def.HEx6).*scl{k}.DefEq(9:end);

% Calculation of the parts of the Jacobian defined by the definition of
% heat exchanger 1
colind{k+1} = colind{k}(17:24);
Jacdef{k+1} = sparse(1:numel(Ceqdef{k+1}),colind{k+1},scl{k}.DefEq(9:end)'.*scl{k}.Var(17:24),...
                     numel(Ceqdef{k+1}),nvar);
